# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class HookLog(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            request_id = schemas.StrSchema
            correlation_id = schemas.StrSchema
            created_at = schemas.StrSchema
            
            
            class events(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'events':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            __annotations__ = {
                "request_id": request_id,
                "correlation_id": correlation_id,
                "created_at": created_at,
                "events": events,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["request_id"]) -> MetaOapg.properties.request_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["correlation_id"]) -> MetaOapg.properties.correlation_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["events"]) -> MetaOapg.properties.events: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["request_id", "correlation_id", "created_at", "events", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["request_id"]) -> typing.Union[MetaOapg.properties.request_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["correlation_id"]) -> typing.Union[MetaOapg.properties.correlation_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["events"]) -> typing.Union[MetaOapg.properties.events, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["request_id", "correlation_id", "created_at", "events", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        request_id: typing.Union[MetaOapg.properties.request_id, str, schemas.Unset] = schemas.unset,
        correlation_id: typing.Union[MetaOapg.properties.correlation_id, str, schemas.Unset] = schemas.unset,
        created_at: typing.Union[MetaOapg.properties.created_at, str, schemas.Unset] = schemas.unset,
        events: typing.Union[MetaOapg.properties.events, list, tuple, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'HookLog':
        return super().__new__(
            cls,
            *_args,
            request_id=request_id,
            correlation_id=correlation_id,
            created_at=created_at,
            events=events,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_risk_rules.post import CreateRiskRule
from onelogin.paths.api_2_risk_rules_rule_id.delete import DeleteRiskRule
from onelogin.paths.api_2_risk_rules_rule_id.get import GetRiskRule
from onelogin.paths.api_2_risk_verify.post import GetRiskScore
from onelogin.paths.api_2_risk_scores.get import GetRiskScores
from onelogin.paths.api_2_risk_rules.get import ListRiskRules
from onelogin.paths.api_2_risk_events.post import TrackRiskEvent
from onelogin.paths.api_2_risk_rules_rule_id.put import UpdateRiskRule


class VigilanceAIApi(
    CreateRiskRule,
    DeleteRiskRule,
    GetRiskRule,
    GetRiskScore,
    GetRiskScores,
    ListRiskRules,
    TrackRiskEvent,
    UpdateRiskRule,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



from onelogin.paths.api_1_privileges_privilege_id_roles.get import ApiForget
from onelogin.paths.api_1_privileges_privilege_id_roles.post import ApiForpost


class Api1PrivilegesPrivilegeIdRoles(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class BrandApp(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "auth_method",
            "visible",
            "updated_at",
            "connector_id",
            "name",
            "created_at",
            "description",
            "id",
            "auth_method_description",
        }
        
        class properties:
            id = schemas.IntSchema
            updated_at = schemas.StrSchema
            name = schemas.StrSchema
            connector_id = schemas.IntSchema
            auth_method_description = schemas.StrSchema
            description = schemas.StrSchema
            auth_method = schemas.IntSchema
            created_at = schemas.StrSchema
            visible = schemas.BoolSchema
            __annotations__ = {
                "id": id,
                "updated_at": updated_at,
                "name": name,
                "connector_id": connector_id,
                "auth_method_description": auth_method_description,
                "description": description,
                "auth_method": auth_method,
                "created_at": created_at,
                "visible": visible,
            }
    
    auth_method: MetaOapg.properties.auth_method
    visible: MetaOapg.properties.visible
    updated_at: MetaOapg.properties.updated_at
    connector_id: MetaOapg.properties.connector_id
    name: MetaOapg.properties.name
    created_at: MetaOapg.properties.created_at
    description: MetaOapg.properties.description
    id: MetaOapg.properties.id
    auth_method_description: MetaOapg.properties.auth_method_description
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["connector_id"]) -> MetaOapg.properties.connector_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["auth_method_description"]) -> MetaOapg.properties.auth_method_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["auth_method"]) -> MetaOapg.properties.auth_method: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["visible"]) -> MetaOapg.properties.visible: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "updated_at", "name", "connector_id", "auth_method_description", "description", "auth_method", "created_at", "visible", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["connector_id"]) -> MetaOapg.properties.connector_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["auth_method_description"]) -> MetaOapg.properties.auth_method_description: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["description"]) -> MetaOapg.properties.description: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["auth_method"]) -> MetaOapg.properties.auth_method: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["visible"]) -> MetaOapg.properties.visible: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "updated_at", "name", "connector_id", "auth_method_description", "description", "auth_method", "created_at", "visible", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        auth_method: typing.Union[MetaOapg.properties.auth_method, decimal.Decimal, int, ],
        visible: typing.Union[MetaOapg.properties.visible, bool, ],
        updated_at: typing.Union[MetaOapg.properties.updated_at, str, ],
        connector_id: typing.Union[MetaOapg.properties.connector_id, decimal.Decimal, int, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        created_at: typing.Union[MetaOapg.properties.created_at, str, ],
        description: typing.Union[MetaOapg.properties.description, str, ],
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, ],
        auth_method_description: typing.Union[MetaOapg.properties.auth_method_description, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'BrandApp':
        return super().__new__(
            cls,
            *_args,
            auth_method=auth_method,
            visible=visible,
            updated_at=updated_at,
            connector_id=connector_id,
            name=name,
            created_at=created_at,
            description=description,
            id=id,
            auth_method_description=auth_method_description,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class AuthServerConfiguration(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    Authorization server configuration
    """


    class MetaOapg:
        required = {
            "resource_identifier",
            "audiences",
        }
        
        class properties:
            
            
            class audiences(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'audiences':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            resource_identifier = schemas.StrSchema
            refresh_token_expiration_minutes = schemas.IntSchema
            access_token_expiration_minutes = schemas.IntSchema
            __annotations__ = {
                "audiences": audiences,
                "resource_identifier": resource_identifier,
                "refresh_token_expiration_minutes": refresh_token_expiration_minutes,
                "access_token_expiration_minutes": access_token_expiration_minutes,
            }
    
    resource_identifier: MetaOapg.properties.resource_identifier
    audiences: MetaOapg.properties.audiences
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["audiences"]) -> MetaOapg.properties.audiences: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["resource_identifier"]) -> MetaOapg.properties.resource_identifier: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["refresh_token_expiration_minutes"]) -> MetaOapg.properties.refresh_token_expiration_minutes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["access_token_expiration_minutes"]) -> MetaOapg.properties.access_token_expiration_minutes: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["audiences", "resource_identifier", "refresh_token_expiration_minutes", "access_token_expiration_minutes", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["audiences"]) -> MetaOapg.properties.audiences: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["resource_identifier"]) -> MetaOapg.properties.resource_identifier: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["refresh_token_expiration_minutes"]) -> typing.Union[MetaOapg.properties.refresh_token_expiration_minutes, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["access_token_expiration_minutes"]) -> typing.Union[MetaOapg.properties.access_token_expiration_minutes, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["audiences", "resource_identifier", "refresh_token_expiration_minutes", "access_token_expiration_minutes", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        resource_identifier: typing.Union[MetaOapg.properties.resource_identifier, str, ],
        audiences: typing.Union[MetaOapg.properties.audiences, list, tuple, ],
        refresh_token_expiration_minutes: typing.Union[MetaOapg.properties.refresh_token_expiration_minutes, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        access_token_expiration_minutes: typing.Union[MetaOapg.properties.access_token_expiration_minutes, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'AuthServerConfiguration':
        return super().__new__(
            cls,
            *_args,
            resource_identifier=resource_identifier,
            audiences=audiences,
            refresh_token_expiration_minutes=refresh_token_expiration_minutes,
            access_token_expiration_minutes=access_token_expiration_minutes,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class SamlFactor(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "device_id",
            "state_token",
            "app_id",
        }
        
        class properties:
            app_id = schemas.StrSchema
            device_id = schemas.StrSchema
            state_token = schemas.StrSchema
            otp_token = schemas.StrSchema
            do_not_notify = schemas.BoolSchema
            __annotations__ = {
                "app_id": app_id,
                "device_id": device_id,
                "state_token": state_token,
                "otp_token": otp_token,
                "do_not_notify": do_not_notify,
            }
    
    device_id: MetaOapg.properties.device_id
    state_token: MetaOapg.properties.state_token
    app_id: MetaOapg.properties.app_id
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["app_id"]) -> MetaOapg.properties.app_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["device_id"]) -> MetaOapg.properties.device_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["state_token"]) -> MetaOapg.properties.state_token: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["otp_token"]) -> MetaOapg.properties.otp_token: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["do_not_notify"]) -> MetaOapg.properties.do_not_notify: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["app_id", "device_id", "state_token", "otp_token", "do_not_notify", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["app_id"]) -> MetaOapg.properties.app_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["device_id"]) -> MetaOapg.properties.device_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["state_token"]) -> MetaOapg.properties.state_token: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["otp_token"]) -> typing.Union[MetaOapg.properties.otp_token, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["do_not_notify"]) -> typing.Union[MetaOapg.properties.do_not_notify, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["app_id", "device_id", "state_token", "otp_token", "do_not_notify", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        device_id: typing.Union[MetaOapg.properties.device_id, str, ],
        state_token: typing.Union[MetaOapg.properties.state_token, str, ],
        app_id: typing.Union[MetaOapg.properties.app_id, str, ],
        otp_token: typing.Union[MetaOapg.properties.otp_token, str, schemas.Unset] = schemas.unset,
        do_not_notify: typing.Union[MetaOapg.properties.do_not_notify, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SamlFactor':
        return super().__new__(
            cls,
            *_args,
            device_id=device_id,
            state_token=state_token,
            app_id=app_id,
            otp_token=otp_token,
            do_not_notify=do_not_notify,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_users.post import CreateUser2
from onelogin.paths.api_2_users_user_id.delete import DeleteUser2
from onelogin.paths.api_2_users_user_id.get import GetUser2
from onelogin.paths.api_2_users_user_id_apps.get import GetUserApps2
from onelogin.paths.api_2_users.get import ListUsers2
from onelogin.paths.api_2_users_user_id.put import UpdateUser2


class UsersV2Api(
    CreateUser2,
    DeleteUser2,
    GetUser2,
    GetUserApps2,
    ListUsers2,
    UpdateUser2,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class SamlAssert(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "password",
            "subdomain",
            "username_or_email",
            "app_id",
        }
        
        class properties:
            username_or_email = schemas.StrSchema
            password = schemas.StrSchema
            app_id = schemas.StrSchema
            subdomain = schemas.StrSchema
            ip_address = schemas.StrSchema
            __annotations__ = {
                "username_or_email": username_or_email,
                "password": password,
                "app_id": app_id,
                "subdomain": subdomain,
                "ip_address": ip_address,
            }
    
    password: MetaOapg.properties.password
    subdomain: MetaOapg.properties.subdomain
    username_or_email: MetaOapg.properties.username_or_email
    app_id: MetaOapg.properties.app_id
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["username_or_email"]) -> MetaOapg.properties.username_or_email: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["password"]) -> MetaOapg.properties.password: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["app_id"]) -> MetaOapg.properties.app_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["subdomain"]) -> MetaOapg.properties.subdomain: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["ip_address"]) -> MetaOapg.properties.ip_address: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["username_or_email", "password", "app_id", "subdomain", "ip_address", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["username_or_email"]) -> MetaOapg.properties.username_or_email: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["password"]) -> MetaOapg.properties.password: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["app_id"]) -> MetaOapg.properties.app_id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["subdomain"]) -> MetaOapg.properties.subdomain: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["ip_address"]) -> typing.Union[MetaOapg.properties.ip_address, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["username_or_email", "password", "app_id", "subdomain", "ip_address", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        password: typing.Union[MetaOapg.properties.password, str, ],
        subdomain: typing.Union[MetaOapg.properties.subdomain, str, ],
        username_or_email: typing.Union[MetaOapg.properties.username_or_email, str, ],
        app_id: typing.Union[MetaOapg.properties.app_id, str, ],
        ip_address: typing.Union[MetaOapg.properties.ip_address, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SamlAssert':
        return super().__new__(
            cls,
            *_args,
            password=password,
            subdomain=subdomain,
            username_or_email=username_or_email,
            app_id=app_id,
            ip_address=ip_address,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class Brand(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "custom_label_text_for_login_screen",
            "login_instruction",
            "custom_masking_color",
            "custom_masking_opacity",
            "enabled",
            "mfa_enrollment_message",
            "custom_color",
            "background",
            "custom_support_enabled",
            "enable_custom_label_for_login_screen",
            "hide_onelogin_footer",
            "logo",
            "custom_accent_color",
            "id",
            "login_instruction_title",
        }
        
        class properties:
            id = schemas.IntSchema
            enabled = schemas.BoolSchema
            custom_support_enabled = schemas.BoolSchema
            custom_color = schemas.StrSchema
            custom_accent_color = schemas.StrSchema
            custom_masking_color = schemas.StrSchema
            custom_masking_opacity = schemas.IntSchema
            mfa_enrollment_message = schemas.StrSchema
            enable_custom_label_for_login_screen = schemas.BoolSchema
            custom_label_text_for_login_screen = schemas.StrSchema
            login_instruction = schemas.StrSchema
            login_instruction_title = schemas.StrSchema
            hide_onelogin_footer = schemas.BoolSchema
            
            
            class background(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    required = {
                        "urls",
                        "content_type",
                        "updated_at",
                        "file_size",
                    }
                    
                    class properties:
                        
                        
                        class urls(
                            schemas.DictSchema
                        ):
                        
                        
                            class MetaOapg:
                                required = {
                                    "original",
                                    "branding",
                                    "login",
                                }
                                
                                class properties:
                                    original = schemas.StrSchema
                                    login = schemas.StrSchema
                                    branding = schemas.StrSchema
                                    __annotations__ = {
                                        "original": original,
                                        "login": login,
                                        "branding": branding,
                                    }
                            
                            original: MetaOapg.properties.original
                            branding: MetaOapg.properties.branding
                            login: MetaOapg.properties.login
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["original"]) -> MetaOapg.properties.original: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["login"]) -> MetaOapg.properties.login: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["branding"]) -> MetaOapg.properties.branding: ...
                            
                            @typing.overload
                            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                            
                            def __getitem__(self, name: typing.Union[typing_extensions.Literal["original", "login", "branding", ], str]):
                                # dict_instance[name] accessor
                                return super().__getitem__(name)
                            
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["original"]) -> MetaOapg.properties.original: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["login"]) -> MetaOapg.properties.login: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["branding"]) -> MetaOapg.properties.branding: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                            
                            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["original", "login", "branding", ], str]):
                                return super().get_item_oapg(name)
                            
                        
                            def __new__(
                                cls,
                                *_args: typing.Union[dict, frozendict.frozendict, ],
                                original: typing.Union[MetaOapg.properties.original, str, ],
                                branding: typing.Union[MetaOapg.properties.branding, str, ],
                                login: typing.Union[MetaOapg.properties.login, str, ],
                                _configuration: typing.Optional[schemas.Configuration] = None,
                                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                            ) -> 'urls':
                                return super().__new__(
                                    cls,
                                    *_args,
                                    original=original,
                                    branding=branding,
                                    login=login,
                                    _configuration=_configuration,
                                    **kwargs,
                                )
                        file_size = schemas.IntSchema
                        updated_at = schemas.StrSchema
                        content_type = schemas.StrSchema
                        __annotations__ = {
                            "urls": urls,
                            "file_size": file_size,
                            "updated_at": updated_at,
                            "content_type": content_type,
                        }
                
                urls: MetaOapg.properties.urls
                content_type: MetaOapg.properties.content_type
                updated_at: MetaOapg.properties.updated_at
                file_size: MetaOapg.properties.file_size
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["urls"]) -> MetaOapg.properties.urls: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["file_size"]) -> MetaOapg.properties.file_size: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["content_type"]) -> MetaOapg.properties.content_type: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["urls", "file_size", "updated_at", "content_type", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["urls"]) -> MetaOapg.properties.urls: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["file_size"]) -> MetaOapg.properties.file_size: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["content_type"]) -> MetaOapg.properties.content_type: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["urls", "file_size", "updated_at", "content_type", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    urls: typing.Union[MetaOapg.properties.urls, dict, frozendict.frozendict, ],
                    content_type: typing.Union[MetaOapg.properties.content_type, str, ],
                    updated_at: typing.Union[MetaOapg.properties.updated_at, str, ],
                    file_size: typing.Union[MetaOapg.properties.file_size, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'background':
                    return super().__new__(
                        cls,
                        *_args,
                        urls=urls,
                        content_type=content_type,
                        updated_at=updated_at,
                        file_size=file_size,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class logo(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    required = {
                        "urls",
                        "content_type",
                        "updated_at",
                        "file_size",
                    }
                    
                    class properties:
                        
                        
                        class urls(
                            schemas.DictSchema
                        ):
                        
                        
                            class MetaOapg:
                                required = {
                                    "navigation",
                                    "original",
                                    "login",
                                }
                                
                                class properties:
                                    original = schemas.StrSchema
                                    login = schemas.StrSchema
                                    navigation = schemas.StrSchema
                                    __annotations__ = {
                                        "original": original,
                                        "login": login,
                                        "navigation": navigation,
                                    }
                            
                            navigation: MetaOapg.properties.navigation
                            original: MetaOapg.properties.original
                            login: MetaOapg.properties.login
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["original"]) -> MetaOapg.properties.original: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["login"]) -> MetaOapg.properties.login: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["navigation"]) -> MetaOapg.properties.navigation: ...
                            
                            @typing.overload
                            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                            
                            def __getitem__(self, name: typing.Union[typing_extensions.Literal["original", "login", "navigation", ], str]):
                                # dict_instance[name] accessor
                                return super().__getitem__(name)
                            
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["original"]) -> MetaOapg.properties.original: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["login"]) -> MetaOapg.properties.login: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["navigation"]) -> MetaOapg.properties.navigation: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                            
                            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["original", "login", "navigation", ], str]):
                                return super().get_item_oapg(name)
                            
                        
                            def __new__(
                                cls,
                                *_args: typing.Union[dict, frozendict.frozendict, ],
                                navigation: typing.Union[MetaOapg.properties.navigation, str, ],
                                original: typing.Union[MetaOapg.properties.original, str, ],
                                login: typing.Union[MetaOapg.properties.login, str, ],
                                _configuration: typing.Optional[schemas.Configuration] = None,
                                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                            ) -> 'urls':
                                return super().__new__(
                                    cls,
                                    *_args,
                                    navigation=navigation,
                                    original=original,
                                    login=login,
                                    _configuration=_configuration,
                                    **kwargs,
                                )
                        file_size = schemas.IntSchema
                        updated_at = schemas.StrSchema
                        content_type = schemas.StrSchema
                        __annotations__ = {
                            "urls": urls,
                            "file_size": file_size,
                            "updated_at": updated_at,
                            "content_type": content_type,
                        }
                
                urls: MetaOapg.properties.urls
                content_type: MetaOapg.properties.content_type
                updated_at: MetaOapg.properties.updated_at
                file_size: MetaOapg.properties.file_size
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["urls"]) -> MetaOapg.properties.urls: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["file_size"]) -> MetaOapg.properties.file_size: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["content_type"]) -> MetaOapg.properties.content_type: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["urls", "file_size", "updated_at", "content_type", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["urls"]) -> MetaOapg.properties.urls: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["file_size"]) -> MetaOapg.properties.file_size: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["content_type"]) -> MetaOapg.properties.content_type: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["urls", "file_size", "updated_at", "content_type", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    urls: typing.Union[MetaOapg.properties.urls, dict, frozendict.frozendict, ],
                    content_type: typing.Union[MetaOapg.properties.content_type, str, ],
                    updated_at: typing.Union[MetaOapg.properties.updated_at, str, ],
                    file_size: typing.Union[MetaOapg.properties.file_size, decimal.Decimal, int, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'logo':
                    return super().__new__(
                        cls,
                        *_args,
                        urls=urls,
                        content_type=content_type,
                        updated_at=updated_at,
                        file_size=file_size,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "id": id,
                "enabled": enabled,
                "custom_support_enabled": custom_support_enabled,
                "custom_color": custom_color,
                "custom_accent_color": custom_accent_color,
                "custom_masking_color": custom_masking_color,
                "custom_masking_opacity": custom_masking_opacity,
                "mfa_enrollment_message": mfa_enrollment_message,
                "enable_custom_label_for_login_screen": enable_custom_label_for_login_screen,
                "custom_label_text_for_login_screen": custom_label_text_for_login_screen,
                "login_instruction": login_instruction,
                "login_instruction_title": login_instruction_title,
                "hide_onelogin_footer": hide_onelogin_footer,
                "background": background,
                "logo": logo,
            }
    
    custom_label_text_for_login_screen: MetaOapg.properties.custom_label_text_for_login_screen
    login_instruction: MetaOapg.properties.login_instruction
    custom_masking_color: MetaOapg.properties.custom_masking_color
    custom_masking_opacity: MetaOapg.properties.custom_masking_opacity
    enabled: MetaOapg.properties.enabled
    mfa_enrollment_message: MetaOapg.properties.mfa_enrollment_message
    custom_color: MetaOapg.properties.custom_color
    background: MetaOapg.properties.background
    custom_support_enabled: MetaOapg.properties.custom_support_enabled
    enable_custom_label_for_login_screen: MetaOapg.properties.enable_custom_label_for_login_screen
    hide_onelogin_footer: MetaOapg.properties.hide_onelogin_footer
    logo: MetaOapg.properties.logo
    custom_accent_color: MetaOapg.properties.custom_accent_color
    id: MetaOapg.properties.id
    login_instruction_title: MetaOapg.properties.login_instruction_title
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enabled"]) -> MetaOapg.properties.enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_support_enabled"]) -> MetaOapg.properties.custom_support_enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_color"]) -> MetaOapg.properties.custom_color: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_accent_color"]) -> MetaOapg.properties.custom_accent_color: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_masking_color"]) -> MetaOapg.properties.custom_masking_color: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_masking_opacity"]) -> MetaOapg.properties.custom_masking_opacity: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["mfa_enrollment_message"]) -> MetaOapg.properties.mfa_enrollment_message: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enable_custom_label_for_login_screen"]) -> MetaOapg.properties.enable_custom_label_for_login_screen: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["custom_label_text_for_login_screen"]) -> MetaOapg.properties.custom_label_text_for_login_screen: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["login_instruction"]) -> MetaOapg.properties.login_instruction: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["login_instruction_title"]) -> MetaOapg.properties.login_instruction_title: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["hide_onelogin_footer"]) -> MetaOapg.properties.hide_onelogin_footer: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["background"]) -> MetaOapg.properties.background: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["logo"]) -> MetaOapg.properties.logo: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "enabled", "custom_support_enabled", "custom_color", "custom_accent_color", "custom_masking_color", "custom_masking_opacity", "mfa_enrollment_message", "enable_custom_label_for_login_screen", "custom_label_text_for_login_screen", "login_instruction", "login_instruction_title", "hide_onelogin_footer", "background", "logo", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enabled"]) -> MetaOapg.properties.enabled: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_support_enabled"]) -> MetaOapg.properties.custom_support_enabled: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_color"]) -> MetaOapg.properties.custom_color: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_accent_color"]) -> MetaOapg.properties.custom_accent_color: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_masking_color"]) -> MetaOapg.properties.custom_masking_color: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_masking_opacity"]) -> MetaOapg.properties.custom_masking_opacity: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["mfa_enrollment_message"]) -> MetaOapg.properties.mfa_enrollment_message: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enable_custom_label_for_login_screen"]) -> MetaOapg.properties.enable_custom_label_for_login_screen: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["custom_label_text_for_login_screen"]) -> MetaOapg.properties.custom_label_text_for_login_screen: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["login_instruction"]) -> MetaOapg.properties.login_instruction: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["login_instruction_title"]) -> MetaOapg.properties.login_instruction_title: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["hide_onelogin_footer"]) -> MetaOapg.properties.hide_onelogin_footer: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["background"]) -> MetaOapg.properties.background: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["logo"]) -> MetaOapg.properties.logo: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "enabled", "custom_support_enabled", "custom_color", "custom_accent_color", "custom_masking_color", "custom_masking_opacity", "mfa_enrollment_message", "enable_custom_label_for_login_screen", "custom_label_text_for_login_screen", "login_instruction", "login_instruction_title", "hide_onelogin_footer", "background", "logo", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        custom_label_text_for_login_screen: typing.Union[MetaOapg.properties.custom_label_text_for_login_screen, str, ],
        login_instruction: typing.Union[MetaOapg.properties.login_instruction, str, ],
        custom_masking_color: typing.Union[MetaOapg.properties.custom_masking_color, str, ],
        custom_masking_opacity: typing.Union[MetaOapg.properties.custom_masking_opacity, decimal.Decimal, int, ],
        enabled: typing.Union[MetaOapg.properties.enabled, bool, ],
        mfa_enrollment_message: typing.Union[MetaOapg.properties.mfa_enrollment_message, str, ],
        custom_color: typing.Union[MetaOapg.properties.custom_color, str, ],
        background: typing.Union[MetaOapg.properties.background, dict, frozendict.frozendict, ],
        custom_support_enabled: typing.Union[MetaOapg.properties.custom_support_enabled, bool, ],
        enable_custom_label_for_login_screen: typing.Union[MetaOapg.properties.enable_custom_label_for_login_screen, bool, ],
        hide_onelogin_footer: typing.Union[MetaOapg.properties.hide_onelogin_footer, bool, ],
        logo: typing.Union[MetaOapg.properties.logo, dict, frozendict.frozendict, ],
        custom_accent_color: typing.Union[MetaOapg.properties.custom_accent_color, str, ],
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, ],
        login_instruction_title: typing.Union[MetaOapg.properties.login_instruction_title, str, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Brand':
        return super().__new__(
            cls,
            *_args,
            custom_label_text_for_login_screen=custom_label_text_for_login_screen,
            login_instruction=login_instruction,
            custom_masking_color=custom_masking_color,
            custom_masking_opacity=custom_masking_opacity,
            enabled=enabled,
            mfa_enrollment_message=mfa_enrollment_message,
            custom_color=custom_color,
            background=background,
            custom_support_enabled=custom_support_enabled,
            enable_custom_label_for_login_screen=enable_custom_label_for_login_screen,
            hide_onelogin_footer=hide_onelogin_footer,
            logo=logo,
            custom_accent_color=custom_accent_color,
            id=id,
            login_instruction_title=login_instruction_title,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_1_users_user_id_otp_devices_device_id_trigger.post import ActivateMfaFactors
from onelogin.paths.api_1_users_user_id_otp_devices.post import EnrollMfaFactor
from onelogin.paths.api_1_users_user_id_mfa_token.post import GenerateMfAtoken
from onelogin.paths.api_1_users_user_id_otp_devices.get import GetEnrolledFactors
from onelogin.paths.api_1_users_user_id_auth_factor.get import GetMfaFactors
from onelogin.paths.api_1_users_user_id_otp_devices_device_id.delete import RemoveMfaFactors
from onelogin.paths.api_1_users_user_id_otp_devices_device_id_verify.post import VerifyMfaFactor


class MultiFactorAuthenticationV1Api(
    ActivateMfaFactors,
    EnrollMfaFactor,
    GenerateMfAtoken,
    GetEnrolledFactors,
    GetMfaFactors,
    RemoveMfaFactors,
    VerifyMfaFactor,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

import unittest
from unittest.mock import patch

import urllib3

import onelogin
from onelogin.paths.api_2_mfa_users_user_id_mfa_token import post  # noqa: E501
from onelogin import configuration, schemas, api_client

from .. import ApiTestMixin


class TestApi2MfaUsersUserIdMfaToken(ApiTestMixin, unittest.TestCase):
    """
    Api2MfaUsersUserIdMfaToken unit test stubs
        Generate MFA token  # noqa: E501
    """
    _configuration = configuration.Configuration()

    def setUp(self):
        used_api_client = api_client.ApiClient(configuration=self._configuration)
        self.api = post.ApiForpost(api_client=used_api_client)  # noqa: E501

    def tearDown(self):
        pass

    response_status = 201




if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class Mapping(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "match",
            "name",
            "position",
            "conditions",
            "actions",
            "enabled",
        }
        
        class properties:
            name = schemas.StrSchema
            enabled = schemas.BoolSchema
            
            
            class match(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "all": "ALL",
                        "any": "ANY",
                    }
                
                @schemas.classproperty
                def ALL(cls):
                    return cls("all")
                
                @schemas.classproperty
                def ANY(cls):
                    return cls("any")
            position = schemas.IntSchema
            
            
            class conditions(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Condition']:
                        return Condition
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Condition'], typing.List['Condition']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'conditions':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Condition':
                    return super().__getitem__(i)
            
            
            class actions(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['ActionObj']:
                        return ActionObj
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['ActionObj'], typing.List['ActionObj']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'actions':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'ActionObj':
                    return super().__getitem__(i)
            id = schemas.IntSchema
            __annotations__ = {
                "name": name,
                "enabled": enabled,
                "match": match,
                "position": position,
                "conditions": conditions,
                "actions": actions,
                "id": id,
            }
    
    match: MetaOapg.properties.match
    name: MetaOapg.properties.name
    position: MetaOapg.properties.position
    conditions: MetaOapg.properties.conditions
    actions: MetaOapg.properties.actions
    enabled: MetaOapg.properties.enabled
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enabled"]) -> MetaOapg.properties.enabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["match"]) -> MetaOapg.properties.match: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["position"]) -> MetaOapg.properties.position: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["conditions"]) -> MetaOapg.properties.conditions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["actions"]) -> MetaOapg.properties.actions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "enabled", "match", "position", "conditions", "actions", "id", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enabled"]) -> MetaOapg.properties.enabled: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["match"]) -> MetaOapg.properties.match: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["position"]) -> MetaOapg.properties.position: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["conditions"]) -> MetaOapg.properties.conditions: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["actions"]) -> MetaOapg.properties.actions: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "enabled", "match", "position", "conditions", "actions", "id", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        match: typing.Union[MetaOapg.properties.match, str, ],
        name: typing.Union[MetaOapg.properties.name, str, ],
        position: typing.Union[MetaOapg.properties.position, decimal.Decimal, int, ],
        conditions: typing.Union[MetaOapg.properties.conditions, list, tuple, ],
        actions: typing.Union[MetaOapg.properties.actions, list, tuple, ],
        enabled: typing.Union[MetaOapg.properties.enabled, bool, ],
        id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Mapping':
        return super().__new__(
            cls,
            *_args,
            match=match,
            name=name,
            position=position,
            conditions=conditions,
            actions=actions,
            enabled=enabled,
            id=id,
            _configuration=_configuration,
            **kwargs,
        )

from onelogin.model.action_obj import ActionObj
from onelogin.model.condition import Condition



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class ConfigurationOidc(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "login_url",
            "access_token_expiration_minutes",
            "refresh_token_expiration_minutes",
            "redirect_uri",
            "oidc_application_type",
            "token_endpoint_auth_method",
        }
        
        class properties:
            login_url = schemas.StrSchema
            redirect_uri = schemas.StrSchema
            access_token_expiration_minutes = schemas.IntSchema
            refresh_token_expiration_minutes = schemas.IntSchema
            
            
            class token_endpoint_auth_method(
                schemas.EnumBase,
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        0: "POSITIVE_0",
                        1: "POSITIVE_1",
                        2: "POSITIVE_2",
                    }
                
                @schemas.classproperty
                def POSITIVE_0(cls):
                    return cls(0)
                
                @schemas.classproperty
                def POSITIVE_1(cls):
                    return cls(1)
                
                @schemas.classproperty
                def POSITIVE_2(cls):
                    return cls(2)
            
            
            class oidc_application_type(
                schemas.EnumBase,
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        0: "POSITIVE_0",
                        1: "POSITIVE_1",
                    }
                
                @schemas.classproperty
                def POSITIVE_0(cls):
                    return cls(0)
                
                @schemas.classproperty
                def POSITIVE_1(cls):
                    return cls(1)
            __annotations__ = {
                "login_url": login_url,
                "redirect_uri": redirect_uri,
                "access_token_expiration_minutes": access_token_expiration_minutes,
                "refresh_token_expiration_minutes": refresh_token_expiration_minutes,
                "token_endpoint_auth_method": token_endpoint_auth_method,
                "oidc_application_type": oidc_application_type,
            }
    
    login_url: MetaOapg.properties.login_url
    access_token_expiration_minutes: MetaOapg.properties.access_token_expiration_minutes
    refresh_token_expiration_minutes: MetaOapg.properties.refresh_token_expiration_minutes
    redirect_uri: MetaOapg.properties.redirect_uri
    oidc_application_type: MetaOapg.properties.oidc_application_type
    token_endpoint_auth_method: MetaOapg.properties.token_endpoint_auth_method
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["login_url"]) -> MetaOapg.properties.login_url: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["redirect_uri"]) -> MetaOapg.properties.redirect_uri: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["access_token_expiration_minutes"]) -> MetaOapg.properties.access_token_expiration_minutes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["refresh_token_expiration_minutes"]) -> MetaOapg.properties.refresh_token_expiration_minutes: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_endpoint_auth_method"]) -> MetaOapg.properties.token_endpoint_auth_method: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["oidc_application_type"]) -> MetaOapg.properties.oidc_application_type: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["login_url", "redirect_uri", "access_token_expiration_minutes", "refresh_token_expiration_minutes", "token_endpoint_auth_method", "oidc_application_type", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["login_url"]) -> MetaOapg.properties.login_url: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["redirect_uri"]) -> MetaOapg.properties.redirect_uri: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["access_token_expiration_minutes"]) -> MetaOapg.properties.access_token_expiration_minutes: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["refresh_token_expiration_minutes"]) -> MetaOapg.properties.refresh_token_expiration_minutes: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_endpoint_auth_method"]) -> MetaOapg.properties.token_endpoint_auth_method: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["oidc_application_type"]) -> MetaOapg.properties.oidc_application_type: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["login_url", "redirect_uri", "access_token_expiration_minutes", "refresh_token_expiration_minutes", "token_endpoint_auth_method", "oidc_application_type", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        login_url: typing.Union[MetaOapg.properties.login_url, str, ],
        access_token_expiration_minutes: typing.Union[MetaOapg.properties.access_token_expiration_minutes, decimal.Decimal, int, ],
        refresh_token_expiration_minutes: typing.Union[MetaOapg.properties.refresh_token_expiration_minutes, decimal.Decimal, int, ],
        redirect_uri: typing.Union[MetaOapg.properties.redirect_uri, str, ],
        oidc_application_type: typing.Union[MetaOapg.properties.oidc_application_type, decimal.Decimal, int, ],
        token_endpoint_auth_method: typing.Union[MetaOapg.properties.token_endpoint_auth_method, decimal.Decimal, int, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'ConfigurationOidc':
        return super().__new__(
            cls,
            *_args,
            login_url=login_url,
            access_token_expiration_minutes=access_token_expiration_minutes,
            refresh_token_expiration_minutes=refresh_token_expiration_minutes,
            redirect_uri=redirect_uri,
            oidc_application_type=oidc_application_type,
            token_endpoint_auth_method=token_endpoint_auth_method,
            _configuration=_configuration,
            **kwargs,
        )



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from onelogin.paths.api_2_roles_role_id_admins.post import AddRoleAdmins
from onelogin.paths.api_2_roles_role_id_users.post import AddRoleUsers
from onelogin.paths.api_2_roles.post import CreateRole
from onelogin.paths.api_2_roles_role_id.delete import DeleteRole
from onelogin.paths.api_2_roles_role_id.get import GetRole
from onelogin.paths.api_2_roles_role_id_admins.get import GetRoleAdmins
from onelogin.paths.api_2_roles_role_id_apps.get import GetRoleApps
from onelogin.paths.api_1_roles_role_id.get import GetRoleById
from onelogin.paths.api_1_roles.get import GetRoleByName
from onelogin.paths.api_2_roles_role_id_users.get import GetRoleUsers
from onelogin.paths.api_2_roles.get import ListRoles
from onelogin.paths.api_2_roles_role_id_admins.delete import RemoveRoleAdmins
from onelogin.paths.api_2_roles_role_id_users.delete import RemoveRoleUsers
from onelogin.paths.api_2_roles_role_id_apps.put import SetRoleApps
from onelogin.paths.api_2_roles_role_id.put import UpdateRole


class RolesApi(
    AddRoleAdmins,
    AddRoleUsers,
    CreateRole,
    DeleteRole,
    GetRole,
    GetRoleAdmins,
    GetRoleApps,
    GetRoleById,
    GetRoleByName,
    GetRoleUsers,
    ListRoles,
    RemoveRoleAdmins,
    RemoveRoleUsers,
    SetRoleApps,
    UpdateRole,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from onelogin import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401

from onelogin.model.error import Error

from . import path

# Query params
IgnoreVisibilitySchema = schemas.BoolSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'ignore_visibility': typing.Union[IgnoreVisibilitySchema, bool, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_ignore_visibility = api_client.QueryParameter(
    name="ignore_visibility",
    style=api_client.ParameterStyle.FORM,
    schema=IgnoreVisibilitySchema,
    explode=True,
)
# Path params
UserIdSchema = schemas.IntSchema
RequestRequiredPathParams = typing_extensions.TypedDict(
    'RequestRequiredPathParams',
    {
        'user_id': typing.Union[UserIdSchema, decimal.Decimal, int, ],
    }
)
RequestOptionalPathParams = typing_extensions.TypedDict(
    'RequestOptionalPathParams',
    {
    },
    total=False
)


class RequestPathParams(RequestRequiredPathParams, RequestOptionalPathParams):
    pass


request_path_user_id = api_client.PathParameter(
    name="user_id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=UserIdSchema,
    required=True,
)
_auth = [
    'OAuth2',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.ListSchema
):


    class MetaOapg:
        
        
        class items(
            schemas.DictSchema
        ):
        
        
            class MetaOapg:
                
                class properties:
                    id = schemas.IntSchema
                    icon_url = schemas.StrSchema
                    extension = schemas.BoolSchema
                    login_id = schemas.IntSchema
                    name = schemas.StrSchema
                    
                    
                    class provisioning_status(
                        schemas.EnumBase,
                        schemas.StrSchema
                    ):
                    
                    
                        class MetaOapg:
                            enum_value_to_name = {
                                "enabling": "ENABLING",
                                "disabling": "DISABLING",
                                "enabling_pending_approval": "ENABLING_PENDING_APPROVAL",
                                "disabling_pendding_approval": "DISABLING_PENDDING_APPROVAL",
                                "enabled": "ENABLED",
                                "disabled": "DISABLED",
                                "disabling_failed": "DISABLING_FAILED",
                                "enabling_failed": "ENABLING_FAILED",
                            }
                        
                        @schemas.classproperty
                        def ENABLING(cls):
                            return cls("enabling")
                        
                        @schemas.classproperty
                        def DISABLING(cls):
                            return cls("disabling")
                        
                        @schemas.classproperty
                        def ENABLING_PENDING_APPROVAL(cls):
                            return cls("enabling_pending_approval")
                        
                        @schemas.classproperty
                        def DISABLING_PENDDING_APPROVAL(cls):
                            return cls("disabling_pendding_approval")
                        
                        @schemas.classproperty
                        def ENABLED(cls):
                            return cls("enabled")
                        
                        @schemas.classproperty
                        def DISABLED(cls):
                            return cls("disabled")
                        
                        @schemas.classproperty
                        def DISABLING_FAILED(cls):
                            return cls("disabling_failed")
                        
                        @schemas.classproperty
                        def ENABLING_FAILED(cls):
                            return cls("enabling_failed")
                    
                    
                    class provisioning_state(
                        schemas.EnumBase,
                        schemas.StrSchema
                    ):
                    
                    
                        class MetaOapg:
                            enum_value_to_name = {
                                "unknown": "UNKNOWN",
                                "provisioning": "PROVISIONING",
                                "modifying": "MODIFYING",
                                "deleting": "DELETING",
                                "provisioning_pending_approval": "PROVISIONING_PENDING_APPROVAL",
                                "deleting_pending_approval": "DELETING_PENDING_APPROVAL",
                                "modifying_pending_approval": "MODIFYING_PENDING_APPROVAL",
                                "linking": "LINKING",
                                "provisioned": "PROVISIONED",
                                "deleted": "DELETED",
                                "modifying_failed": "MODIFYING_FAILED",
                                "provisioning_failed": "PROVISIONING_FAILED",
                                "deleting_failed": "DELETING_FAILED",
                                "linking_failed": "LINKING_FAILED",
                                "disabled": "DISABLED",
                                "nonexistent": "NONEXISTENT",
                                "modifying_pending_approval_then_disabled": "MODIFYING_PENDING_APPROVAL_THEN_DISABLED",
                            }
                        
                        @schemas.classproperty
                        def UNKNOWN(cls):
                            return cls("unknown")
                        
                        @schemas.classproperty
                        def PROVISIONING(cls):
                            return cls("provisioning")
                        
                        @schemas.classproperty
                        def MODIFYING(cls):
                            return cls("modifying")
                        
                        @schemas.classproperty
                        def DELETING(cls):
                            return cls("deleting")
                        
                        @schemas.classproperty
                        def PROVISIONING_PENDING_APPROVAL(cls):
                            return cls("provisioning_pending_approval")
                        
                        @schemas.classproperty
                        def DELETING_PENDING_APPROVAL(cls):
                            return cls("deleting_pending_approval")
                        
                        @schemas.classproperty
                        def MODIFYING_PENDING_APPROVAL(cls):
                            return cls("modifying_pending_approval")
                        
                        @schemas.classproperty
                        def LINKING(cls):
                            return cls("linking")
                        
                        @schemas.classproperty
                        def PROVISIONED(cls):
                            return cls("provisioned")
                        
                        @schemas.classproperty
                        def DELETED(cls):
                            return cls("deleted")
                        
                        @schemas.classproperty
                        def MODIFYING_FAILED(cls):
                            return cls("modifying_failed")
                        
                        @schemas.classproperty
                        def PROVISIONING_FAILED(cls):
                            return cls("provisioning_failed")
                        
                        @schemas.classproperty
                        def DELETING_FAILED(cls):
                            return cls("deleting_failed")
                        
                        @schemas.classproperty
                        def LINKING_FAILED(cls):
                            return cls("linking_failed")
                        
                        @schemas.classproperty
                        def DISABLED(cls):
                            return cls("disabled")
                        
                        @schemas.classproperty
                        def NONEXISTENT(cls):
                            return cls("nonexistent")
                        
                        @schemas.classproperty
                        def MODIFYING_PENDING_APPROVAL_THEN_DISABLED(cls):
                            return cls("modifying_pending_approval_then_disabled")
                    provisioning_enabled = schemas.BoolSchema
                    __annotations__ = {
                        "id": id,
                        "icon_url": icon_url,
                        "extension": extension,
                        "login_id": login_id,
                        "name": name,
                        "provisioning_status": provisioning_status,
                        "provisioning_state": provisioning_state,
                        "provisioning_enabled": provisioning_enabled,
                    }
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["icon_url"]) -> MetaOapg.properties.icon_url: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["extension"]) -> MetaOapg.properties.extension: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["login_id"]) -> MetaOapg.properties.login_id: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["provisioning_status"]) -> MetaOapg.properties.provisioning_status: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["provisioning_state"]) -> MetaOapg.properties.provisioning_state: ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["provisioning_enabled"]) -> MetaOapg.properties.provisioning_enabled: ...
            
            @typing.overload
            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
            
            def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "icon_url", "extension", "login_id", "name", "provisioning_status", "provisioning_state", "provisioning_enabled", ], str]):
                # dict_instance[name] accessor
                return super().__getitem__(name)
            
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["icon_url"]) -> typing.Union[MetaOapg.properties.icon_url, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["extension"]) -> typing.Union[MetaOapg.properties.extension, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["login_id"]) -> typing.Union[MetaOapg.properties.login_id, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["provisioning_status"]) -> typing.Union[MetaOapg.properties.provisioning_status, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["provisioning_state"]) -> typing.Union[MetaOapg.properties.provisioning_state, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["provisioning_enabled"]) -> typing.Union[MetaOapg.properties.provisioning_enabled, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
            
            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "icon_url", "extension", "login_id", "name", "provisioning_status", "provisioning_state", "provisioning_enabled", ], str]):
                return super().get_item_oapg(name)
            
        
            def __new__(
                cls,
                *_args: typing.Union[dict, frozendict.frozendict, ],
                id: typing.Union[MetaOapg.properties.id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                icon_url: typing.Union[MetaOapg.properties.icon_url, str, schemas.Unset] = schemas.unset,
                extension: typing.Union[MetaOapg.properties.extension, bool, schemas.Unset] = schemas.unset,
                login_id: typing.Union[MetaOapg.properties.login_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                provisioning_status: typing.Union[MetaOapg.properties.provisioning_status, str, schemas.Unset] = schemas.unset,
                provisioning_state: typing.Union[MetaOapg.properties.provisioning_state, str, schemas.Unset] = schemas.unset,
                provisioning_enabled: typing.Union[MetaOapg.properties.provisioning_enabled, bool, schemas.Unset] = schemas.unset,
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'items':
                return super().__new__(
                    cls,
                    *_args,
                    id=id,
                    icon_url=icon_url,
                    extension=extension,
                    login_id=login_id,
                    name=name,
                    provisioning_status=provisioning_status,
                    provisioning_state=provisioning_state,
                    provisioning_enabled=provisioning_enabled,
                    _configuration=_configuration,
                    **kwargs,
                )

    def __new__(
        cls,
        _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
        _configuration: typing.Optional[schemas.Configuration] = None,
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            _arg,
            _configuration=_configuration,
        )

    def __getitem__(self, i: int) -> MetaOapg.items:
        return super().__getitem__(i)


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)
SchemaFor401ResponseBodyApplicationJson = Error


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor401ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor401ResponseBodyApplicationJson),
    },
)
SchemaFor404ResponseBodyApplicationJson = Error


@dataclass
class ApiResponseFor404(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor404ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_404 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor404,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor404ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '200': _response_for_200,
    '401': _response_for_401,
    '404': _response_for_404,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _get_user_apps2_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def _get_user_apps2_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _get_user_apps2_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _get_user_apps2_oapg(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Get User Apps
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        self._verify_typed_dict_inputs_oapg(RequestPathParams, path_params)
        used_path = path.value

        _path_params = {}
        for parameter in (
            request_path_user_id,
        ):
            parameter_data = path_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            serialized_data = parameter.serialize(parameter_data)
            _path_params.update(serialized_data)

        for k, v in _path_params.items():
            used_path = used_path.replace('{%s}' % k, v)

        prefix_separator_iterator = None
        for parameter in (
            request_query_ignore_visibility,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class GetUserApps2(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def get_user_apps2(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get_user_apps2(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get_user_apps2(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get_user_apps2(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_user_apps2_oapg(
            query_params=query_params,
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor200,
    ]: ...

    @typing.overload
    def get(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def get(
        self,
        query_params: RequestQueryParams = frozendict.frozendict(),
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._get_user_apps2_oapg(
            query_params=query_params,
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from onelogin import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401

from onelogin.model.error import Error

from . import path

# Path params
MappingIdSchema = schemas.IntSchema
RequestRequiredPathParams = typing_extensions.TypedDict(
    'RequestRequiredPathParams',
    {
        'mapping_id': typing.Union[MappingIdSchema, decimal.Decimal, int, ],
    }
)
RequestOptionalPathParams = typing_extensions.TypedDict(
    'RequestOptionalPathParams',
    {
    },
    total=False
)


class RequestPathParams(RequestRequiredPathParams, RequestOptionalPathParams):
    pass


request_path_mapping_id = api_client.PathParameter(
    name="mapping_id",
    style=api_client.ParameterStyle.SIMPLE,
    schema=MappingIdSchema,
    required=True,
)
_auth = [
    'OAuth2',
]


@dataclass
class ApiResponseFor204(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_204 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor204,
)
SchemaFor401ResponseBodyApplicationJson = Error


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor401ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor401ResponseBodyApplicationJson),
    },
)
SchemaFor404ResponseBodyApplicationJson = Error


@dataclass
class ApiResponseFor404(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor404ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_404 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor404,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor404ResponseBodyApplicationJson),
    },
)
_status_code_to_response = {
    '204': _response_for_204,
    '401': _response_for_401,
    '404': _response_for_404,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):
    @typing.overload
    def _delete_mapping_oapg(
        self,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor204,
    ]: ...

    @typing.overload
    def _delete_mapping_oapg(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def _delete_mapping_oapg(
        self,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor204,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def _delete_mapping_oapg(
        self,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        """
        Delete Mapping
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestPathParams, path_params)
        used_path = path.value

        _path_params = {}
        for parameter in (
            request_path_mapping_id,
        ):
            parameter_data = path_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            serialized_data = parameter.serialize(parameter_data)
            _path_params.update(serialized_data)

        for k, v in _path_params.items():
            used_path = used_path.replace('{%s}' % k, v)

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='delete'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(
                status=response.status,
                reason=response.reason,
                api_response=api_response
            )

        return api_response


class DeleteMapping(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    @typing.overload
    def delete_mapping(
        self,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor204,
    ]: ...

    @typing.overload
    def delete_mapping(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def delete_mapping(
        self,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor204,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def delete_mapping(
        self,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._delete_mapping_oapg(
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiFordelete(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    @typing.overload
    def delete(
        self,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: typing_extensions.Literal[False] = ...,
    ) -> typing.Union[
        ApiResponseFor204,
    ]: ...

    @typing.overload
    def delete(
        self,
        skip_deserialization: typing_extensions.Literal[True],
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
    ) -> api_client.ApiResponseWithoutDeserialization: ...

    @typing.overload
    def delete(
        self,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = ...,
    ) -> typing.Union[
        ApiResponseFor204,
        api_client.ApiResponseWithoutDeserialization,
    ]: ...

    def delete(
        self,
        path_params: RequestPathParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ):
        return self._delete_mapping_oapg(
            path_params=path_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





from onelogin.paths.api_1_users_user_id_otp_devices.get import ApiForget
from onelogin.paths.api_1_users_user_id_otp_devices.post import ApiForpost


class Api1UsersUserIdOtpDevices(
    ApiForget,
    ApiForpost,
):
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class Hook(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        required = {
            "retries",
            "function",
            "runtime",
            "disabled",
            "packages",
            "type",
            "timeout",
            "env_vars",
        }
        
        class properties:
            type = schemas.StrSchema
            disabled = schemas.BoolSchema
            timeout = schemas.IntSchema
            
            
            class env_vars(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'env_vars':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            runtime = schemas.StrSchema
            
            
            class retries(
                schemas.IntSchema
            ):
            
            
                class MetaOapg:
                    inclusive_maximum = 4
            
            
            class packages(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    additional_properties = schemas.StrSchema
                
                def __getitem__(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                def get_item_oapg(self, name: typing.Union[str, ]) -> MetaOapg.additional_properties:
                    return super().get_item_oapg(name)
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[MetaOapg.additional_properties, str, ],
                ) -> 'packages':
                    return super().__new__(
                        cls,
                        *_args,
                        _configuration=_configuration,
                        **kwargs,
                    )
            function = schemas.StrSchema
            id = schemas.StrSchema
            context_version = schemas.StrSchema
            
            
            class status(
                schemas.EnumBase,
                schemas.StrSchema
            ):
            
            
                class MetaOapg:
                    enum_value_to_name = {
                        "ready": "READY",
                        "create-queued": "CREATEQUEUED",
                        "create-running": "CREATERUNNING",
                        "create-failed": "CREATEFAILED",
                        "update-queued": "UPDATEQUEUED",
                        "update-running": "UPDATERUNNING",
                        "update-failed": "UPDATEFAILED",
                    }
                
                @schemas.classproperty
                def READY(cls):
                    return cls("ready")
                
                @schemas.classproperty
                def CREATEQUEUED(cls):
                    return cls("create-queued")
                
                @schemas.classproperty
                def CREATERUNNING(cls):
                    return cls("create-running")
                
                @schemas.classproperty
                def CREATEFAILED(cls):
                    return cls("create-failed")
                
                @schemas.classproperty
                def UPDATEQUEUED(cls):
                    return cls("update-queued")
                
                @schemas.classproperty
                def UPDATERUNNING(cls):
                    return cls("update-running")
                
                @schemas.classproperty
                def UPDATEFAILED(cls):
                    return cls("update-failed")
            
            
            class options(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        risk_enabled = schemas.BoolSchema
                        location_enabled = schemas.BoolSchema
                        mfa_device_info_enabled = schemas.BoolSchema
                        __annotations__ = {
                            "risk_enabled": risk_enabled,
                            "location_enabled": location_enabled,
                            "mfa_device_info_enabled": mfa_device_info_enabled,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["risk_enabled"]) -> MetaOapg.properties.risk_enabled: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["location_enabled"]) -> MetaOapg.properties.location_enabled: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["mfa_device_info_enabled"]) -> MetaOapg.properties.mfa_device_info_enabled: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["risk_enabled", "location_enabled", "mfa_device_info_enabled", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["risk_enabled"]) -> typing.Union[MetaOapg.properties.risk_enabled, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["location_enabled"]) -> typing.Union[MetaOapg.properties.location_enabled, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["mfa_device_info_enabled"]) -> typing.Union[MetaOapg.properties.mfa_device_info_enabled, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["risk_enabled", "location_enabled", "mfa_device_info_enabled", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *_args: typing.Union[dict, frozendict.frozendict, ],
                    risk_enabled: typing.Union[MetaOapg.properties.risk_enabled, bool, schemas.Unset] = schemas.unset,
                    location_enabled: typing.Union[MetaOapg.properties.location_enabled, bool, schemas.Unset] = schemas.unset,
                    mfa_device_info_enabled: typing.Union[MetaOapg.properties.mfa_device_info_enabled, bool, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'options':
                    return super().__new__(
                        cls,
                        *_args,
                        risk_enabled=risk_enabled,
                        location_enabled=location_enabled,
                        mfa_device_info_enabled=mfa_device_info_enabled,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class conditions(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    @staticmethod
                    def items() -> typing.Type['Condition']:
                        return Condition
            
                def __new__(
                    cls,
                    _arg: typing.Union[typing.Tuple['Condition'], typing.List['Condition']],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'conditions':
                    return super().__new__(
                        cls,
                        _arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> 'Condition':
                    return super().__getitem__(i)
            created_at = schemas.StrSchema
            updated_at = schemas.StrSchema
            __annotations__ = {
                "type": type,
                "disabled": disabled,
                "timeout": timeout,
                "env_vars": env_vars,
                "runtime": runtime,
                "retries": retries,
                "packages": packages,
                "function": function,
                "id": id,
                "context_version": context_version,
                "status": status,
                "options": options,
                "conditions": conditions,
                "created_at": created_at,
                "updated_at": updated_at,
            }
    
    retries: MetaOapg.properties.retries
    function: MetaOapg.properties.function
    runtime: MetaOapg.properties.runtime
    disabled: MetaOapg.properties.disabled
    packages: MetaOapg.properties.packages
    type: MetaOapg.properties.type
    timeout: MetaOapg.properties.timeout
    env_vars: MetaOapg.properties.env_vars
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["disabled"]) -> MetaOapg.properties.disabled: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["timeout"]) -> MetaOapg.properties.timeout: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["env_vars"]) -> MetaOapg.properties.env_vars: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["runtime"]) -> MetaOapg.properties.runtime: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["retries"]) -> MetaOapg.properties.retries: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["packages"]) -> MetaOapg.properties.packages: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["function"]) -> MetaOapg.properties.function: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["context_version"]) -> MetaOapg.properties.context_version: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["options"]) -> MetaOapg.properties.options: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["conditions"]) -> MetaOapg.properties.conditions: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["type", "disabled", "timeout", "env_vars", "runtime", "retries", "packages", "function", "id", "context_version", "status", "options", "conditions", "created_at", "updated_at", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["type"]) -> MetaOapg.properties.type: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["disabled"]) -> MetaOapg.properties.disabled: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["timeout"]) -> MetaOapg.properties.timeout: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["env_vars"]) -> MetaOapg.properties.env_vars: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["runtime"]) -> MetaOapg.properties.runtime: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["retries"]) -> MetaOapg.properties.retries: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["packages"]) -> MetaOapg.properties.packages: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["function"]) -> MetaOapg.properties.function: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["context_version"]) -> typing.Union[MetaOapg.properties.context_version, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union[MetaOapg.properties.status, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["options"]) -> typing.Union[MetaOapg.properties.options, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["conditions"]) -> typing.Union[MetaOapg.properties.conditions, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> typing.Union[MetaOapg.properties.updated_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["type", "disabled", "timeout", "env_vars", "runtime", "retries", "packages", "function", "id", "context_version", "status", "options", "conditions", "created_at", "updated_at", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        retries: typing.Union[MetaOapg.properties.retries, decimal.Decimal, int, ],
        function: typing.Union[MetaOapg.properties.function, str, ],
        runtime: typing.Union[MetaOapg.properties.runtime, str, ],
        disabled: typing.Union[MetaOapg.properties.disabled, bool, ],
        packages: typing.Union[MetaOapg.properties.packages, dict, frozendict.frozendict, ],
        type: typing.Union[MetaOapg.properties.type, str, ],
        timeout: typing.Union[MetaOapg.properties.timeout, decimal.Decimal, int, ],
        env_vars: typing.Union[MetaOapg.properties.env_vars, list, tuple, ],
        id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
        context_version: typing.Union[MetaOapg.properties.context_version, str, schemas.Unset] = schemas.unset,
        status: typing.Union[MetaOapg.properties.status, str, schemas.Unset] = schemas.unset,
        options: typing.Union[MetaOapg.properties.options, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        conditions: typing.Union[MetaOapg.properties.conditions, list, tuple, schemas.Unset] = schemas.unset,
        created_at: typing.Union[MetaOapg.properties.created_at, str, schemas.Unset] = schemas.unset,
        updated_at: typing.Union[MetaOapg.properties.updated_at, str, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'Hook':
        return super().__new__(
            cls,
            *_args,
            retries=retries,
            function=function,
            runtime=runtime,
            disabled=disabled,
            packages=packages,
            type=type,
            timeout=timeout,
            env_vars=env_vars,
            id=id,
            context_version=context_version,
            status=status,
            options=options,
            conditions=conditions,
            created_at=created_at,
            updated_at=updated_at,
            _configuration=_configuration,
            **kwargs,
        )

from onelogin.model.condition import Condition



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class OauthToken(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        class properties:
            access_token = schemas.StrSchema
            created_at = schemas.StrSchema
            expires_in = schemas.IntSchema
            refresh_token = schemas.StrSchema
            token_type = schemas.StrSchema
            account_id = schemas.IntSchema
            __annotations__ = {
                "access_token": access_token,
                "created_at": created_at,
                "expires_in": expires_in,
                "refresh_token": refresh_token,
                "token_type": token_type,
                "account_id": account_id,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["access_token"]) -> MetaOapg.properties.access_token: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["expires_in"]) -> MetaOapg.properties.expires_in: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["refresh_token"]) -> MetaOapg.properties.refresh_token: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["token_type"]) -> MetaOapg.properties.token_type: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["account_id"]) -> MetaOapg.properties.account_id: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["access_token", "created_at", "expires_in", "refresh_token", "token_type", "account_id", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["access_token"]) -> typing.Union[MetaOapg.properties.access_token, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["expires_in"]) -> typing.Union[MetaOapg.properties.expires_in, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["refresh_token"]) -> typing.Union[MetaOapg.properties.refresh_token, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["token_type"]) -> typing.Union[MetaOapg.properties.token_type, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["account_id"]) -> typing.Union[MetaOapg.properties.account_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["access_token", "created_at", "expires_in", "refresh_token", "token_type", "account_id", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        access_token: typing.Union[MetaOapg.properties.access_token, str, schemas.Unset] = schemas.unset,
        created_at: typing.Union[MetaOapg.properties.created_at, str, schemas.Unset] = schemas.unset,
        expires_in: typing.Union[MetaOapg.properties.expires_in, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        refresh_token: typing.Union[MetaOapg.properties.refresh_token, str, schemas.Unset] = schemas.unset,
        token_type: typing.Union[MetaOapg.properties.token_type, str, schemas.Unset] = schemas.unset,
        account_id: typing.Union[MetaOapg.properties.account_id, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'OauthToken':
        return super().__new__(
            cls,
            *_args,
            access_token=access_token,
            created_at=created_at,
            expires_in=expires_in,
            refresh_token=refresh_token,
            token_type=token_type,
            account_id=account_id,
            _configuration=_configuration,
            **kwargs,
        )



from onelogin.paths.api_2_api_authorizations_api_auth_id_clients.get import ApiForget
from onelogin.paths.api_2_api_authorizations_api_auth_id_clients.post import ApiForpost


class Api2ApiAuthorizationsApiAuthIdClients(
    ApiForget,
    ApiForpost,
):
    pass



from onelogin.paths.api_2_branding_email_settings.get import ApiForget
from onelogin.paths.api_2_branding_email_settings.put import ApiForput
from onelogin.paths.api_2_branding_email_settings.delete import ApiFordelete


class Api2BrandingEmailSettings(
    ApiForget,
    ApiForput,
    ApiFordelete,
):
    pass



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class AppParameters(
    schemas.DictSchema
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.

    The parameters section contains parameterized attributes that have defined at the connector level as well as custom attributes that have been defined specifically for this app. Regardless of how they are defined, all parameters have the following attributes.
Each parameter is an object with the key for the object being set as the parameters short name.
    """


    class MetaOapg:
        
        class properties:
            user_attribute_mappings = schemas.StrSchema
            user_attribute_macros = schemas.StrSchema
            label = schemas.StrSchema
            include_in_saml_assertion = schemas.BoolSchema
            __annotations__ = {
                "user_attribute_mappings": user_attribute_mappings,
                "user_attribute_macros": user_attribute_macros,
                "label": label,
                "include_in_saml_assertion": include_in_saml_assertion,
            }
        additional_properties = schemas.AnyTypeSchema
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user_attribute_mappings"]) -> MetaOapg.properties.user_attribute_mappings: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["user_attribute_macros"]) -> MetaOapg.properties.user_attribute_macros: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["label"]) -> MetaOapg.properties.label: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["include_in_saml_assertion"]) -> MetaOapg.properties.include_in_saml_assertion: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> MetaOapg.additional_properties: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["user_attribute_mappings"], typing_extensions.Literal["user_attribute_macros"], typing_extensions.Literal["label"], typing_extensions.Literal["include_in_saml_assertion"], str, ]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user_attribute_mappings"]) -> typing.Union[MetaOapg.properties.user_attribute_mappings, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["user_attribute_macros"]) -> typing.Union[MetaOapg.properties.user_attribute_macros, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["label"]) -> typing.Union[MetaOapg.properties.label, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["include_in_saml_assertion"]) -> typing.Union[MetaOapg.properties.include_in_saml_assertion, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[MetaOapg.additional_properties, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["user_attribute_mappings"], typing_extensions.Literal["user_attribute_macros"], typing_extensions.Literal["label"], typing_extensions.Literal["include_in_saml_assertion"], str, ]):
        return super().get_item_oapg(name)

    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, ],
        user_attribute_mappings: typing.Union[MetaOapg.properties.user_attribute_mappings, str, schemas.Unset] = schemas.unset,
        user_attribute_macros: typing.Union[MetaOapg.properties.user_attribute_macros, str, schemas.Unset] = schemas.unset,
        label: typing.Union[MetaOapg.properties.label, str, schemas.Unset] = schemas.unset,
        include_in_saml_assertion: typing.Union[MetaOapg.properties.include_in_saml_assertion, bool, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[MetaOapg.additional_properties, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
    ) -> 'AppParameters':
        return super().__new__(
            cls,
            *_args,
            user_attribute_mappings=user_attribute_mappings,
            user_attribute_macros=user_attribute_macros,
            label=label,
            include_in_saml_assertion=include_in_saml_assertion,
            _configuration=_configuration,
            **kwargs,
        )



# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from onelogin.apis.tag_to_api import tag_to_api

import enum


class TagValues(str, enum.Enum):
    OAUTH2 = "OAuth2"
    API_AUTHORIZATION_SERVER = "API Authorization Server"
    API_AUTH_SCOPES = "API Auth: Scopes"
    API_AUTH_CLAIMS = "API Auth: Claims"
    API_AUTH_CLIENT_APPS = "API Auth: Client Apps"
    APPS = "Apps"
    APP_RULES = "App Rules"
    BRANDING_SERVICE = "Branding Service"
    BRANDING_SERVICE_TEMPLATES = "Branding Service: Templates"
    BRANDING_SERVICE_SMTP = "Branding Service: SMTP"
    EVENTS = "Events"
    GROUPS = "Groups"
    INVITE_LINKS = "Invite Links"
    MULTI_FACTOR_AUTHENTICATION = "Multi Factor Authentication"
    MULTI_FACTOR_AUTHENTICATION_V1 = "Multi Factor Authentication V1"
    PRIVILEGES = "Privileges"
    ROLES = "Roles"
    SAML_ASSERTIONS = "SAML Assertions"
    USERS_V1 = "Users V1"
    USERS_V2 = "Users V2"
    USER_MAPPINGS = "User Mappings"
    VIGILANCE_AI = "Vigilance AI"
    SMART_HOOKS = "Smart Hooks"



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from onelogin import schemas  # noqa: F401


class SamlApp(
    schemas.ComposedSchema,
):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """


    class MetaOapg:
        
        
        class all_of_1(
            schemas.DictSchema
        ):
        
        
            class MetaOapg:
                
                class properties:
                
                    @staticmethod
                    def configuration() -> typing.Type['ConfigurationSaml']:
                        return ConfigurationSaml
                
                    @staticmethod
                    def sso() -> typing.Type['SsoSaml']:
                        return SsoSaml
                    
                    
                    class parameters(
                        schemas.DictSchema
                    ):
                    
                    
                        class MetaOapg:
                            required = {
                                "saml_username",
                            }
                            
                            class properties:
                                
                                
                                class saml_username(
                                    schemas.DictSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        required = {
                                            "user_attribute_mappings",
                                        }
                                        
                                        class properties:
                                            user_attribute_mappings = schemas.StrSchema
                                            __annotations__ = {
                                                "user_attribute_mappings": user_attribute_mappings,
                                            }
                                    
                                    user_attribute_mappings: MetaOapg.properties.user_attribute_mappings
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["user_attribute_mappings"]) -> MetaOapg.properties.user_attribute_mappings: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                    
                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["user_attribute_mappings", ], str]):
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)
                                    
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["user_attribute_mappings"]) -> MetaOapg.properties.user_attribute_mappings: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                    
                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["user_attribute_mappings", ], str]):
                                        return super().get_item_oapg(name)
                                    
                                
                                    def __new__(
                                        cls,
                                        *_args: typing.Union[dict, frozendict.frozendict, ],
                                        user_attribute_mappings: typing.Union[MetaOapg.properties.user_attribute_mappings, str, ],
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'saml_username':
                                        return super().__new__(
                                            cls,
                                            *_args,
                                            user_attribute_mappings=user_attribute_mappings,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                                __annotations__ = {
                                    "saml_username": saml_username,
                                }
                        
                        saml_username: MetaOapg.properties.saml_username
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["saml_username"]) -> MetaOapg.properties.saml_username: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["saml_username", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["saml_username"]) -> MetaOapg.properties.saml_username: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["saml_username", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *_args: typing.Union[dict, frozendict.frozendict, ],
                            saml_username: typing.Union[MetaOapg.properties.saml_username, dict, frozendict.frozendict, ],
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'parameters':
                            return super().__new__(
                                cls,
                                *_args,
                                saml_username=saml_username,
                                _configuration=_configuration,
                                **kwargs,
                            )
                    __annotations__ = {
                        "configuration": configuration,
                        "sso": sso,
                        "parameters": parameters,
                    }
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["configuration"]) -> 'ConfigurationSaml': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["sso"]) -> 'SsoSaml': ...
            
            @typing.overload
            def __getitem__(self, name: typing_extensions.Literal["parameters"]) -> MetaOapg.properties.parameters: ...
            
            @typing.overload
            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
            
            def __getitem__(self, name: typing.Union[typing_extensions.Literal["configuration", "sso", "parameters", ], str]):
                # dict_instance[name] accessor
                return super().__getitem__(name)
            
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["configuration"]) -> typing.Union['ConfigurationSaml', schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["sso"]) -> typing.Union['SsoSaml', schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: typing_extensions.Literal["parameters"]) -> typing.Union[MetaOapg.properties.parameters, schemas.Unset]: ...
            
            @typing.overload
            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
            
            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["configuration", "sso", "parameters", ], str]):
                return super().get_item_oapg(name)
            
        
            def __new__(
                cls,
                *_args: typing.Union[dict, frozendict.frozendict, ],
                configuration: typing.Union['ConfigurationSaml', schemas.Unset] = schemas.unset,
                sso: typing.Union['SsoSaml', schemas.Unset] = schemas.unset,
                parameters: typing.Union[MetaOapg.properties.parameters, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                _configuration: typing.Optional[schemas.Configuration] = None,
                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
            ) -> 'all_of_1':
                return super().__new__(
                    cls,
                    *_args,
                    configuration=configuration,
                    sso=sso,
                    parameters=parameters,
                    _configuration=_configuration,
                    **kwargs,
                )
        
        @classmethod
        @functools.lru_cache()
        def all_of(cls):
            # we need this here to make our import statements work
            # we must store _composed_schemas in here so the code is only run
            # when we invoke this method. If we kept this at the class
            # level we would get an error because the class level
            # code would be run when this module is imported, and these composed
            # classes don't exist yet because their module has not finished
            # loading
            return [
                GenericApp,
                cls.all_of_1,
            ]


    def __new__(
        cls,
        *_args: typing.Union[dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, bool, None, list, tuple, bytes, io.FileIO, io.BufferedReader, ],
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SamlApp':
        return super().__new__(
            cls,
            *_args,
            _configuration=_configuration,
            **kwargs,
        )

from onelogin.model.configuration_saml import ConfigurationSaml
from onelogin.model.generic_app import GenericApp
from onelogin.model.sso_saml import SsoSaml



# coding: utf-8

"""
    OneLogin API

    OpenAPI Specification for OneLogin  # noqa: E501

    The version of the OpenAPI document: 3.1.1
    Generated by: https://openapi-generator.tech
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "onelogin"
VERSION = "3.1.6"
# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = [
    "certifi >= 14.5.14",
    "frozendict ~= 2.3.4",
    "python-dateutil ~= 2.7.0",
    "setuptools >= 21.0.0",
    "typing_extensions ~= 4.3.0",
    "urllib3 ~= 1.26.7",
]

setup(
    name=NAME,
    version=VERSION,
    description="OneLogin API",
    author="OneLogin",
    author_email="team@openapitools.org",
    url="",
    keywords=["OpenAPI", "OpenAPI-Generator", "OneLogin API"],
    python_requires=">=3.7",
    install_requires=REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    long_description="""\
    OpenAPI Specification for OneLogin  # noqa: E501
    """
)
